# CHANGELOG

<!-- version list -->

## v1.0.1 (2026-03-22)

### Bug Fixes

- Restructure src
  ([`928a9c3`](https://github.com/celine-eu/ontologies/commit/928a9c3d7a41946913d4ff3bba242ab0bca42f70))


## v1.0.0 (2026-03-22)

- Initial Release
